==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/access_context_manager_service_perimeters/AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.java <==
package com.hashicorp.cdktf.providers.google.access_context_manager_service_perimeters;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:38.465Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.accessContextManagerServicePerimeters.AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom")
@software.amazon.jsii.Jsii.Proxy(AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom extends software.amazon.jsii.JsiiSerializable {

    /**
     * A list of identities that are allowed access through this 'EgressPolicy'.
     * <p>
     * Should be in the format of email address. The email address should
     * represent individual user or service account only.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#identities AccessContextManagerServicePerimeters#identities}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getIdentities() {
        return null;
    }

    /**
     * Specifies the type of identities that are allowed access to outside the perimeter.
     * <p>
     * If left unspecified, then members of 'identities' field will
     * be allowed access. Possible values: ["IDENTITY_TYPE_UNSPECIFIED", "ANY_IDENTITY", "ANY_USER_ACCOUNT", "ANY_SERVICE_ACCOUNT"]
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#identity_type AccessContextManagerServicePerimeters#identity_type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getIdentityType() {
        return null;
    }

    /**
     * Whether to enforce traffic restrictions based on 'sources' field.
     * <p>
     * If the 'sources' field is non-empty, then this field must be set to 'SOURCE_RESTRICTION_ENABLED'. Possible values: ["SOURCE_RESTRICTION_UNSPECIFIED", "SOURCE_RESTRICTION_ENABLED", "SOURCE_RESTRICTION_DISABLED"]
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#source_restriction AccessContextManagerServicePerimeters#source_restriction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceRestriction() {
        return null;
    }

    /**
     * sources block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#sources AccessContextManagerServicePerimeters#sources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getSources() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom> {
        java.util.List<java.lang.String> identities;
        java.lang.String identityType;
        java.lang.String sourceRestriction;
        java.lang.Object sources;

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getIdentities}
         * @param identities A list of identities that are allowed access through this 'EgressPolicy'.
         *                   Should be in the format of email address. The email address should
         *                   represent individual user or service account only.
         *                   
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#identities AccessContextManagerServicePerimeters#identities}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder identities(java.util.List<java.lang.String> identities) {
            this.identities = identities;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getIdentityType}
         * @param identityType Specifies the type of identities that are allowed access to outside the perimeter.
         *                     If left unspecified, then members of 'identities' field will
         *                     be allowed access. Possible values: ["IDENTITY_TYPE_UNSPECIFIED", "ANY_IDENTITY", "ANY_USER_ACCOUNT", "ANY_SERVICE_ACCOUNT"]
         *                     
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#identity_type AccessContextManagerServicePerimeters#identity_type}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder identityType(java.lang.String identityType) {
            this.identityType = identityType;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getSourceRestriction}
         * @param sourceRestriction Whether to enforce traffic restrictions based on 'sources' field.
         *                          If the 'sources' field is non-empty, then this field must be set to 'SOURCE_RESTRICTION_ENABLED'. Possible values: ["SOURCE_RESTRICTION_UNSPECIFIED", "SOURCE_RESTRICTION_ENABLED", "SOURCE_RESTRICTION_DISABLED"]
         *                          
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#source_restriction AccessContextManagerServicePerimeters#source_restriction}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceRestriction(java.lang.String sourceRestriction) {
            this.sourceRestriction = sourceRestriction;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getSources}
         * @param sources sources block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#sources AccessContextManagerServicePerimeters#sources}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sources(com.hashicorp.cdktf.IResolvable sources) {
            this.sources = sources;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getSources}
         * @param sources sources block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/access_context_manager_service_perimeters#sources AccessContextManagerServicePerimeters#sources}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sources(java.util.List<? extends com.hashicorp.cdktf.providers.google.access_context_manager_service_perimeters.AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFromSources> sources) {
            this.sources = sources;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom {
        private final java.util.List<java.lang.String> identities;
        private final java.lang.String identityType;
        private final java.lang.String sourceRestriction;
        private final java.lang.Object sources;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.identities = software.amazon.jsii.Kernel.get(this, "identities", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.identityType = software.amazon.jsii.Kernel.get(this, "identityType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.sourceRestriction = software.amazon.jsii.Kernel.get(this, "sourceRestriction", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.sources = software.amazon.jsii.Kernel.get(this, "sources", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.identities = builder.identities;
            this.identityType = builder.identityType;
            this.sourceRestriction = builder.sourceRestriction;
            this.sources = builder.sources;
        }

        @Override
        public final java.util.List<java.lang.String> getIdentities() {
            return this.identities;
        }

        @Override
        public final java.lang.String getIdentityType() {
            return this.identityType;
        }

        @Override
        public final java.lang.String getSourceRestriction() {
            return this.sourceRestriction;
        }

        @Override
        public final java.lang.Object getSources() {
            return this.sources;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIdentities() != null) {
                data.set("identities", om.valueToTree(this.getIdentities()));
            }
            if (this.getIdentityType() != null) {
                data.set("identityType", om.valueToTree(this.getIdentityType()));
            }
            if (this.getSourceRestriction() != null) {
                data.set("sourceRestriction", om.valueToTree(this.getSourceRestriction()));
            }
            if (this.getSources() != null) {
                data.set("sources", om.valueToTree(this.getSources()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.accessContextManagerServicePerimeters.AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.Jsii$Proxy that = (AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.Jsii$Proxy) o;

            if (this.identities != null ? !this.identities.equals(that.identities) : that.identities != null) return false;
            if (this.identityType != null ? !this.identityType.equals(that.identityType) : that.identityType != null) return false;
            if (this.sourceRestriction != null ? !this.sourceRestriction.equals(that.sourceRestriction) : that.sourceRestriction != null) return false;
            return this.sources != null ? this.sources.equals(that.sources) : that.sources == null;
        }

        @Override
        public final int hashCode() {
            int result = this.identities != null ? this.identities.hashCode() : 0;
            result = 31 * result + (this.identityType != null ? this.identityType.hashCode() : 0);
            result = 31 * result + (this.sourceRestriction != null ? this.sourceRestriction.hashCode() : 0);
            result = 31 * result + (this.sources != null ? this.sources.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/access_context_manager_service_perimeters/AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.java <==
package com.hashicorp.cdktf.providers.google.access_context_manager_service_perimeters;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:12.312Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.accessContextManagerServicePerimeters.AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom")
@software.amazon.jsii.Jsii.Proxy(AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom extends software.amazon.jsii.JsiiSerializable {

    /**
     * 'A list of identities that are allowed access through this 'EgressPolicy'.
     * <p>
     * To specify an identity or identity group, use the IAM v1 format
     * specified [here](https://cloud.google.com/iam/docs/principal-identifiers.md#v1).
     * The following prefixes are supprted: user, group, serviceAccount, principal, and principalSet.'
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#identities AccessContextManagerServicePerimeters#identities}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getIdentities() {
        return null;
    }

    /**
     * Specifies the type of identities that are allowed access to outside the perimeter.
     * <p>
     * If left unspecified, then members of 'identities' field will
     * be allowed access. Possible values: ["IDENTITY_TYPE_UNSPECIFIED", "ANY_IDENTITY", "ANY_USER_ACCOUNT", "ANY_SERVICE_ACCOUNT"]
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#identity_type AccessContextManagerServicePerimeters#identity_type}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getIdentityType() {
        return null;
    }

    /**
     * Whether to enforce traffic restrictions based on 'sources' field.
     * <p>
     * If the 'sources' field is non-empty, then this field must be set to 'SOURCE_RESTRICTION_ENABLED'. Possible values: ["SOURCE_RESTRICTION_UNSPECIFIED", "SOURCE_RESTRICTION_ENABLED", "SOURCE_RESTRICTION_DISABLED"]
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#source_restriction AccessContextManagerServicePerimeters#source_restriction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getSourceRestriction() {
        return null;
    }

    /**
     * sources block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#sources AccessContextManagerServicePerimeters#sources}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getSources() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom> {
        java.util.List<java.lang.String> identities;
        java.lang.String identityType;
        java.lang.String sourceRestriction;
        java.lang.Object sources;

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getIdentities}
         * @param identities 'A list of identities that are allowed access through this 'EgressPolicy'.
         *                   To specify an identity or identity group, use the IAM v1 format
         *                   specified [here](https://cloud.google.com/iam/docs/principal-identifiers.md#v1).
         *                   The following prefixes are supprted: user, group, serviceAccount, principal, and principalSet.'
         *                   
         *                   Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#identities AccessContextManagerServicePerimeters#identities}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder identities(java.util.List<java.lang.String> identities) {
            this.identities = identities;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getIdentityType}
         * @param identityType Specifies the type of identities that are allowed access to outside the perimeter.
         *                     If left unspecified, then members of 'identities' field will
         *                     be allowed access. Possible values: ["IDENTITY_TYPE_UNSPECIFIED", "ANY_IDENTITY", "ANY_USER_ACCOUNT", "ANY_SERVICE_ACCOUNT"]
         *                     
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#identity_type AccessContextManagerServicePerimeters#identity_type}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder identityType(java.lang.String identityType) {
            this.identityType = identityType;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getSourceRestriction}
         * @param sourceRestriction Whether to enforce traffic restrictions based on 'sources' field.
         *                          If the 'sources' field is non-empty, then this field must be set to 'SOURCE_RESTRICTION_ENABLED'. Possible values: ["SOURCE_RESTRICTION_UNSPECIFIED", "SOURCE_RESTRICTION_ENABLED", "SOURCE_RESTRICTION_DISABLED"]
         *                          
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#source_restriction AccessContextManagerServicePerimeters#source_restriction}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sourceRestriction(java.lang.String sourceRestriction) {
            this.sourceRestriction = sourceRestriction;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getSources}
         * @param sources sources block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#sources AccessContextManagerServicePerimeters#sources}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sources(com.hashicorp.cdktf.IResolvable sources) {
            this.sources = sources;
            return this;
        }

        /**
         * Sets the value of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom#getSources}
         * @param sources sources block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/access_context_manager_service_perimeters#sources AccessContextManagerServicePerimeters#sources}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sources(java.util.List<? extends com.hashicorp.cdktf.providers.google.access_context_manager_service_perimeters.AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFromSources> sources) {
            this.sources = sources;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom {
        private final java.util.List<java.lang.String> identities;
        private final java.lang.String identityType;
        private final java.lang.String sourceRestriction;
        private final java.lang.Object sources;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.identities = software.amazon.jsii.Kernel.get(this, "identities", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.identityType = software.amazon.jsii.Kernel.get(this, "identityType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.sourceRestriction = software.amazon.jsii.Kernel.get(this, "sourceRestriction", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.sources = software.amazon.jsii.Kernel.get(this, "sources", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.identities = builder.identities;
            this.identityType = builder.identityType;
            this.sourceRestriction = builder.sourceRestriction;
            this.sources = builder.sources;
        }

        @Override
        public final java.util.List<java.lang.String> getIdentities() {
            return this.identities;
        }

        @Override
        public final java.lang.String getIdentityType() {
            return this.identityType;
        }

        @Override
        public final java.lang.String getSourceRestriction() {
            return this.sourceRestriction;
        }

        @Override
        public final java.lang.Object getSources() {
            return this.sources;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getIdentities() != null) {
                data.set("identities", om.valueToTree(this.getIdentities()));
            }
            if (this.getIdentityType() != null) {
                data.set("identityType", om.valueToTree(this.getIdentityType()));
            }
            if (this.getSourceRestriction() != null) {
                data.set("sourceRestriction", om.valueToTree(this.getSourceRestriction()));
            }
            if (this.getSources() != null) {
                data.set("sources", om.valueToTree(this.getSources()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.accessContextManagerServicePerimeters.AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.Jsii$Proxy that = (AccessContextManagerServicePerimetersServicePerimetersSpecEgressPoliciesEgressFrom.Jsii$Proxy) o;

            if (this.identities != null ? !this.identities.equals(that.identities) : that.identities != null) return false;
            if (this.identityType != null ? !this.identityType.equals(that.identityType) : that.identityType != null) return false;
            if (this.sourceRestriction != null ? !this.sourceRestriction.equals(that.sourceRestriction) : that.sourceRestriction != null) return false;
            return this.sources != null ? this.sources.equals(that.sources) : that.sources == null;
        }

        @Override
        public final int hashCode() {
            int result = this.identities != null ? this.identities.hashCode() : 0;
            result = 31 * result + (this.identityType != null ? this.identityType.hashCode() : 0);
            result = 31 * result + (this.sourceRestriction != null ? this.sourceRestriction.hashCode() : 0);
            result = 31 * result + (this.sources != null ? this.sources.hashCode() : 0);
            return result;
        }
    }
}
